Icons Preview!

# CUSTOM PREVIEW - you can change this in the previewTemplate option

    .icon-avatar:

    .icon-back:

    .icon-bubble:

    .icon-chart-white:

    .icon-chart:

    .icon-check:

    .icon-chevron-down:

    .icon-chevron-up:

    .icon-close-mint:

    .icon-close:

    .icon-facebook:

    .icon-heart:

    .icon-instagram:

    .icon-lang_chevron:

    .icon-location-white:

    .icon-loop2-white:

    .icon-loop2:

    .icon-menu:

    .icon-next-black:

    .icon-next-white:

    .icon-next:

    .icon-open:

    .icon-profiles:

    .icon-search-mint:

    .icon-search:

    .icon-search_spr:

    .icon-search_white:

    .icon-twitter:

    .icon-up-arrow:

    .icon-up:

    .icon-user-check:

    .icon-user:

    .icon-your-answer:

## Embedded SVG option

(The `data-grunticon-embed` attribute tells grunticon to inject SVG inline):

    icon-burger:

    icon-burger (styled variation):